==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/Input/flac/translations/flac_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>FLAC 文件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="183"/>
        <source>About FLAC Audio Plugin</source>
        <translation>关于 FLAC 音频插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="184"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 音频插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="185"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/flac/translations/flac_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="57"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="59"/>
        <source>FLAC Files</source>
        <translation>FLAC 文件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="187"/>
        <source>About FLAC Audio Plugin</source>
        <translation>关于 FLAC 音频插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="188"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 音频插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="189"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation>长度</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation>声音通道</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
